%define	major		2
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define commit		63a9d677a13283ac730ca28729580155d2c7b6b0

Name:		gmic
Version:	2.4.2
Release:	%mkrel 1
Group:		Graphics
# CeCILL version 2.0
License:	CeCILL
Summary:	A script language (G'MIC) dedicated to image processing
Url:		http://gmic.eu/
Source0:	http://gmic.eu/files/source/%{name}_%{version}.tar.xz
Source1:	https://github.com/dtschump/gmic-community/archive/%{commit}/%{name}-community_%{version}.tar.xz
Source2:	zart.desktop
Patch0:		gmic-2.4.2-mga-optflags.patch

BuildRequires:	dos2unix
BuildRequires:	ffmpeg-devel
BuildRequires:	pkgconfig(GraphicsMagick)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(gimp-2.0)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	qttools5

Requires:	%{libname} >= %{version}-%{release}

%description
G'MIC defines a complete image processing framework, and thus
can manage generic image data as other image-related tools.

Anyway, the specific features described below make it a bit particular :

* It internally works with lists of images.
  Image manipulations and interactions can be done
  either grouped or focused on specific items.
* It can process a wide variety of image types,
  including multi-spectral (arbitray number of channels)
  and 3d volumetric images, as well as image sequences,
  or 3d vector objects.
  Images with different pixel types are supported,
  allowing to process flawlessly images with 8bits or
  16bits integers per channel, as well as float-valued datasets.
* It provides small but efficient visualization modules
  dedicated to the exploration/viewing of 2d/3d multi-spectral images,
  3d vector objects (elevation map, isocurves, isosurfaces,...),
  or 1d graph plots.
* It proposes commands to handle custom interactive windows
  where events can be managed easily by the user.
* It is highly extensible through the importation of custom command
  files which add new commands that become understood by the
  language interpreter.
* Most of the functionalities can be used inside GIMP
  via the provided plug-in, allowing end-users to integrate
  any G'MIC-based pipeline directly in a nice GUI,
  without coding efforts.
* It is based on the latest development versions of the CImg Library,
  a well established C++ template image processing toolkit,
  developed by the same team of developers.

%files -f %{name}.lang
%doc COPYING README
#%config(noreplace) %{_sysconfdir}/bash_completion.d/%{name}
%{_bindir}/%{name}
%{_bindir}/%{name}_qt
%{_bindir}/%{name}_krita_qt
%{_mandir}/man1/%{name}.1.*
%{_datadir}/bash-completion/completions/%{name}
#------------------------------------------------------

%package -n zart
Summary:        GUI for G'MIC real-time manipulations on the output of a webcam
Group:          Graphics/Utilities
Provides:	%{name}-zart = %{version}-%{release}

%description -n zart
ZArt is a computer program whose purpose is to demonstrate the possibilities of
the G'MIC image processing language by offering the choice of several
manipulations on a video stream acquired from a webcam.

%files -n zart
%{_bindir}/zart
%{_datadir}/applications/zart.desktop
%{_iconsdir}/hicolor/*/*/zart.png
#%%{_datadir}/zart/haarcascade*.xml

#------------------------------------------------------

%package -n gimp-plugin-%{name}
Summary:	gmic plugin for gimp
Group:		Graphics/Utilities
Requires:	gimp >= 2.6.0
Obsoletes:	%{name}-gimp < 1.5.1.5-1
Provides:	%{name}-gimp = %{version}-%{release}

%description -n gimp-plugin-%{name}
G'MIC has been made available as an easy-to-use plug-in for GIMP.
It extends this retouching software capabilities by offering a large number of
pre-defined image filters and effects.
Of course, the plug-in is highly customizable and it is possible to add your
own custom G'MIC-written filters in it.

%files -n gimp-plugin-%{name}
%{_libdir}/gimp/2.0/plug-ins/%{name}_gimp_qt
%{_libdir}/gimp/2.0/plug-ins/%{name}_film_cluts.gmz

#------------------------------------------------------

%package -n %libname
Summary:	Library for gmic
Group:		System/Libraries

%description -n %libname
This package contains the library needed to run programs
dynamically linked with gmic.

%files -n %libname
%{_libdir}/lib*%{name}.so.%{major}*

#------------------------------------------------------

%package -n %develname
Summary:	Header file for gmic
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Obsoletes:	%{name}-gimp-devel < 1.5.1.5-1
Provides:	%{name}-devel = %{version}-%{release}

%description -n %develname
This package contains the development file for gmic.

%files -n %develname
%{_includedir}/%{name}*.h
%{_libdir}/lib*%{name}.so

#------------------------------------------------------

%prep
%setup -q -a1
dos2unix src/Makefile
%apply_patches

# fix file-not-utf8
iconv -f iso8859-1 -t utf-8 COPYING > COPYING.conv && mv -f COPYING.conv COPYING

# prepare libcgmic from community
mv %{name}-community-%{commit}/libcgmic/* ./src

%build
%setup_compile_flags

pushd src
	%__make all libc NOSTRIP=1
popd

pushd zart
	%qmake_qt5 zart.pro
	%make_build
popd

%install
pushd src
	%make_install LIB=%{_lib}
popd

pushd zart
	install -m 0755 zart %{buildroot}%{_bindir}/zart
	install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/zart.desktop
	install -Dm 0644 images/gmic_hat.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/zart.png
popd

%find_lang %{name} --with-man


%changelog
* Tue Dec 11 2018 adrianomorselli <adrianomorselli> 2.4.2-1uplos2018
- update
